==> centreon-web-25.09.2.tar.gz: centreon-web-25.09.2/src/Core/Infrastructure/Common/Repository/MultiReadSessionRepository.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\Common\Repository;

use Core\Application\Common\Session\Repository\ReadSessionRepositoryInterface;

class MultiReadSessionRepository implements ReadSessionRepositoryInterface
{
    /**
     * @param SystemReadSessionRepository $systemRepository
     * @param DbReadSessionRepository $dbReadSessionRepository
     */
    public function __construct(
        private SystemReadSessionRepository $systemRepository,
        private DbReadSessionRepository $dbReadSessionRepository
    ) {
    }

    /**
     * @inheritDoc
     */
    public function findSessionIdsByUserId(int $userId): array
    {
        return $this->dbReadSessionRepository->findSessionIdsByUserId($userId);
    }

    /**
     * @inheritDoc
     */
    public function getValueFromSession(string $sessionId, string $key): mixed
    {
        return $this->systemRepository->getValueFromSession($sessionId, $key);
    }
}

==> centreon-web-25.10.9.tar.gz: centreon-web-25.10.9/src/Core/Infrastructure/Common/Repository/MultiReadSessionRepository.php <==
<?php

/*
 * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Infrastructure\Common\Repository;

use Core\Application\Common\Session\Repository\ReadSessionRepositoryInterface;

class MultiReadSessionRepository implements ReadSessionRepositoryInterface
{
    /**
     * @param SystemReadSessionRepository $systemRepository
     * @param DbReadSessionRepository $dbReadSessionRepository
     */
    public function __construct(
        private SystemReadSessionRepository $systemRepository,
        private DbReadSessionRepository $dbReadSessionRepository,
    ) {
    }

    /**
     * @inheritDoc
     */
    public function findSessionIdsByUserId(int $userId): array
    {
        return $this->dbReadSessionRepository->findSessionIdsByUserId($userId);
    }

    /**
     * @inheritDoc
     */
    public function getValueFromSession(string $sessionId, string $key): mixed
    {
        return $this->systemRepository->getValueFromSession($sessionId, $key);
    }
}
